// Copyright (C) 2020 VIRNECT CO., LTD.
// All rights reserved.

#pragma once
#include <VARAPI/TrackingFramework/Commons.hpp>

namespace VIRNECT {
namespace TOOLS {

/**
 * @brief Tool to read camera calibration files
 * @param jsonPath Path to JSON file
 * @param cameraCalibration Camera calibration instance to be set
 * @return Success of file reading and calibration check
 */
VARAPI_EXPORT bool readCalibrationFile(const std::string& jsonPath, CameraCalibration& cameraCalibration);

/**
 * @brief Set a file sequence as image source
 * @param imageSequencePath Path to folder containing sequential images
 * @param loop If the sequence should be looped
 * @return Success or failure of initialization
 */
VARAPI_EXPORT bool activateImageSourceFileSequence(const std::string& imageSequencePath, bool loop = false);

/**
 * @brief Set the USBCamera as image source
 * @param id Id of the USB camera
 * @return Success or failure of initialization
 */
VARAPI_EXPORT bool activateImageSourceUSBCamera(int32_t id = 0);

/**
 * @brief Enable or disable automatic USB camera control. Needs to be set before calling activateImageSourceUSBCamera()
 * @param enabled Value to set
 * @return Success or failure of setting the parameter
 */
VARAPI_EXPORT bool useAutomaticUSBCameraSetting(bool enabled = true);

namespace RECORDER {

/**
 * @brief Will record the camera input stream. For each call of the process function, the current frame is saved as an individual JPG or PGM image
 * @param folderPath Root folder path to save the recording. Sub folders will be generated
 * @param pgmFormat If the images should be saved as PGM instead of JPG
 * @return If the recording started successfully
 */
VARAPI_EXPORT bool startRecording(const std::string& folderPath, bool pgmFormat = false);

/**
 * @brief Will stop the recording
 * @return If the recording stopped successfully
 */
VARAPI_EXPORT bool stopRecording();

/**
 * @brief Indicates if the recording is currently active
 * @return True if the recording is active
 */
VARAPI_EXPORT bool isRecording();

} // namespace RECORDER
} // namespace TOOLS
} // namespace VIRNECT
